{*******************************************************************************

  DSGNAPP.PAS
  Version 1.0
  7th September 1997

  Author : Frederic Vanmol
  e-mail : rogevanm@skynet.be

  Target : Delphi 1, 2 and 3, C++Builder

  Comments : This unit is donated to the public domain.

  Purpose : With TDesignApp, you can set some properties of TApplication, like
             HintColor and OnIdle, at design time. If you make any changes to
             the component, I would love to see them.

*******************************************************************************}
unit
    DsgnApp;

interface

uses
    Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs;


type
  TDesignApp = class(TComponent)
  private
    FHelpFile              : String;
    FHintColor             : TColor;
    FHintHidePause,
    FHintPause,
    FHintShortPause        : Integer;
    FShowHint,
    FShowMainForm          : Boolean;
    FTitle                 : String;
    FUpdateFormatSettings,
    FUpdateMetricSettings  : Boolean;

    FOnActivate,
    FOnDeactivate          : TNotifyEvent;
    FOnException           : TExceptionEvent;
    FOnHelp                : THelpEvent;
    FOnHint                : TNotifyEvent;
    FOnIdle                : TIdleEvent;
    FOnMessage             : TMessageEvent;
    FOnMinimize,
    FOnRestore             : TNotifyEvent;
    FOnShowHint            : TShowHintEvent;

    function GetHelpFile: String;
    procedure SetHelpFile(NewValue: String);
    function GetHintColor: TColor;
    procedure SetHintColor(NewValue: TColor);
    function GetHintHidePause: Integer;
    procedure SetHintHidePause(NewValue: Integer);
    function GetHintPause: Integer;
    procedure SetHintPause(NewValue: Integer);
    function GetHintShortPause: Integer;
    procedure SetHintShortPause(NewValue: Integer);
    function GetShowHint: Boolean;
    procedure SetShowHint(NewValue: Boolean);
    function GetShowMainForm: Boolean;
    procedure SetShowMainForm(NewValue: Boolean);
    function GetTitle: String;
    procedure SetTitle(NewValue: String);
    function GetUpdateFormatSettings: Boolean;
    procedure SetUpdateFormatSettings(NewValue: Boolean);
    function GetUpdateMetricSettings: Boolean;
    procedure SetUpdateMetricSettings(NewValue: Boolean);
    function GetOnActivate: TNotifyEvent;
    procedure SetOnActivate(NewValue: TNotifyEvent);
    function GetOnDeActivate: TNotifyEvent;
    procedure SetOnDeActivate(NewValue: TNotifyEvent);
    function GetOnException: TExceptionEvent;
    procedure SetOnException(NewValue: TExceptionEvent);
    function GetOnHelp: THelpEvent;
    procedure SetOnHelp(NewValue: THelpEvent);
    function GetOnHint: TNotifyEvent;
    procedure SetOnHint(NewValue: TNotifyEvent);
    function GetOnIdle: TIdleEvent;
    procedure SetOnIdle(NewValue: TIdleEvent);
    function GetOnMessage: TMessageEvent;
    procedure SetOnMessage(NewValue: TMessageEvent);
    function GetOnMinimize: TNotifyEvent;
    procedure SetOnMinimize(NewValue: TNotifyEvent);
    function GetOnRestore: TNotifyEvent;
    procedure SetOnRestore(NewValue: TNotifyEvent);
    function GetOnShowHint: TShowHintEvent;
    procedure SetOnShowHint(NewValue: TShowHintEvent);
  protected
    procedure Loaded; override;
  public
    constructor Create(aOwner: TComponent); override;
  published
    property HelpFile: String read GetHelpFile write SetHelpFile;
    property HintColor: TColor read GetHintColor write SetHintColor default clInfoBk;
    property HintHidePause: Integer read GetHintHidePause write SetHintHidePause default 2500;
    property HintPause: Integer read GetHintPause write SetHintPause default 500;
    property HintShortPause: Integer read GetHintShortPause write SetHintShortPause default 50;
    property ShowHint: Boolean read GetShowHint write SetShowHint default TRUE;
    property ShowMainForm: Boolean read GetShowMainForm write SetShowMainForm default TRUE;
    property Title: String read GetTitle write SetTitle;
    property UpdateFormatSettings: Boolean read GetUpdateFormatSettings
                                           write SetUpdateFormatSettings default TRUE;
    property UpdateMetricSettings: Boolean read GetUpdateMetricSettings
                                           write SetUpdateMetricSettings default TRUE;

    property OnActivate: TNotifyEvent read GetOnActivate write SetOnActivate;
    property OnDeactivate: TNotifyEvent read GetOnDeActivate write SetOnDeActivate;
    property OnException: TExceptionEvent read GetOnException write SetOnException;
    property OnHelp: THelpEvent read GetOnHelp write SetOnHelp;
    property OnHint: TNotifyEvent read GetOnHint write SetOnHint;
    property OnIdle: TIdleEvent read GetOnIdle write SetOnIdle;
    property OnMessage: TMessageEvent read GetOnMessage write SetOnMessage;
    property OnMinimize: TNotifyEvent read GetOnMinimize write SetOnMinimize;
    property OnRestore: TNotifyEvent read GetOnRestore write SetOnRestore;
    property OnShowHint: TShowHintEvent read GetOnShowHint write SetOnShowHint;
  end;



procedure Register;





implementation


constructor TDesignApp.Create;
begin
  inherited Create(aOwner);
  FHelpFile := '';
  FHintColor := clInfoBk;
  FHintHidePause := 2500;
  FHintPause := 500;
  FHintShortPause := 50;
  FShowHint := TRUE;
  FShowMainForm := TRUE;
  FTitle := '';
  FUpdateFormatSettings := TRUE;
  FUpdateMetricSettings := TRUE;
  FOnActivate := nil;
  FOnDeactivate := nil;
  FOnException := nil;
  FOnHelp := nil;
  FOnHint := nil;
  FOnIdle := nil;
  FOnMessage := nil;
  FOnMinimize := nil;
  FOnRestore := nil;
  FOnShowHint := nil;
end;


procedure TDesignApp.Loaded;
begin
  HelpFile := FHelpFile;
  HintColor := FHintColor;
  HintHidePause := FHintHidePause;
  HintPause := FHintPause;
  HintShortPause := FHintShortPause;
  ShowHint := FShowHint;
  ShowMainForm := FShowMainForm;
  Title := FTitle;
  UpdateFormatSettings := FUpdateFormatSettings;
  UpdateMetricSettings := FUpdateMetricSettings;
  OnActivate := FOnActivate;
  OnDeActivate := FOnDeactivate;
  OnException := FOnException;
  OnHelp := FOnHelp;
  OnHint := FOnHint;
  OnIdle := FOnIdle;
  OnMessage := FOnMessage;
  OnMinimize := FOnMinimize;
  OnRestore := FOnRestore;
  OnShowHint := FOnShowHint;
end;



function TDesignApp.GetHelpFile: String;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.HelpFile
  else
    Result := FHelpFile;
end;


procedure TDesignApp.SetHelpFile(NewValue: String);
begin
  FHelpFile := NewValue;
  if not (csDesigning in ComponentState) then
    Application.HelpFile := NewValue;
end;


function TDesignApp.GetHintColor: TColor;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.HintColor
  else
    Result := FHintColor;
end;


procedure TDesignApp.SetHintColor(NewValue: TColor);
begin
  FHintColor := NewValue;
  if not (csDesigning in ComponentState) then
    Application.HintColor := NewValue;
end;


function TDesignApp.GetHintHidePause: Integer;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.HintHidePause
  else
    Result := FHintHidePause;
end;


procedure TDesignApp.SetHintHidePause(NewValue: Integer);
begin
  FHintHidePause := NewValue;
  if not (csDesigning in ComponentState) then
    Application.HintHidePause := NewValue;
end;


function TDesignApp.GetHintPause: Integer;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.HintPause
  else
    Result := FHintPause;
end;


procedure TDesignApp.SetHintPause(NewValue: Integer);
begin
  FHintPause := NewValue;
  if not (csDesigning in ComponentState) then
    Application.HintPause := NewValue;
end;


function TDesignApp.GetHintShortPause: Integer;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.HintShortPause
  else
    Result := FHintShortPause;
end;


procedure TDesignApp.SetHintShortPause(NewValue: Integer);
begin
  FHintShortPause := NewValue;
  if not (csDesigning in ComponentState) then
    Application.HintShortPause := NewValue;
end;


function TDesignApp.GetShowHint: Boolean;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.ShowHint
  else
    Result := FShowHint;
end;


procedure TDesignApp.SetShowHint(NewValue: Boolean);
begin
  FShowHint := NewValue;
  if not (csDesigning in ComponentState) then
    Application.ShowHint := NewValue;
end;


function TDesignApp.GetShowMainForm: Boolean;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.ShowMainForm
  else
    Result := FShowMainForm;
end;


procedure TDesignApp.SetShowMainForm(NewValue: Boolean);
begin
  FShowMainForm := NewValue;
  if not (csDesigning in ComponentState) then
    Application.ShowMainForm := NewValue;
end;


function TDesignApp.GetTitle: String;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.Title
  else
    Result := FTitle;
end;


procedure TDesignApp.SetTitle(NewValue: String);
begin
  FTitle := NewValue;
  if not (csDesigning in ComponentState) then
    Application.Title := NewValue;
end;


function TDesignApp.GetUpdateFormatSettings: Boolean;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.UpdateFormatSettings
  else
    Result := FUpdateFormatSettings;
end;


procedure TDesignApp.SetUpdateFormatSettings(NewValue: Boolean);
begin
  FUpdateFormatSettings := NewValue;
  if not (csDesigning in ComponentState) then
    Application.UpdateFormatSettings := NewValue;
end;


function TDesignApp.GetUpdateMetricSettings: Boolean;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.UpdateMetricSettings
  else
    Result := FUpdateMetricSettings;
end;


procedure TDesignApp.SetUpdateMetricSettings(NewValue: Boolean);
begin
  FUpdateMetricSettings := NewValue;
  if not (csDesigning in ComponentState) then
    Application.UpdateMetricSettings := NewValue;
end;


function TDesignApp.GetOnActivate: TNotifyEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnActivate
  else
    Result := FOnActivate;
end;


procedure TDesignApp.SetOnActivate(NewValue: TNotifyEvent);
begin
  FOnActivate := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnActivate := NewValue;
end;


function TDesignApp.GetOnDeActivate: TNotifyEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnDeActivate
  else
    Result := FOnDeActivate;
end;


procedure TDesignApp.SetOnDeActivate(NewValue: TNotifyEvent);
begin
  FOnDeActivate := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnDeActivate := NewValue;
end;


function TDesignApp.GetOnException: TExceptionEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnException
  else
    Result := FOnException;
end;


procedure TDesignApp.SetOnException(NewValue: TExceptionEvent);
begin
  FOnException := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnException := NewValue;
end;


function TDesignApp.GetOnHelp: THelpEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnHelp
  else
    Result := FOnHelp;
end;


procedure TDesignApp.SetOnHelp(NewValue: THelpEvent);
begin
  FOnHelp := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnHelp := NewValue;
end;


function TDesignApp.GetOnHint: TNotifyEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnHint
  else
    Result := FOnHint;
end;


procedure TDesignApp.SetOnHint(NewValue: TNotifyEvent);
begin
  FOnHint := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnHint := NewValue;
end;


function TDesignApp.GetOnIdle: TIdleEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnIdle
  else
    Result := FOnIdle;
end;


procedure TDesignApp.SetOnIdle(NewValue: TIdleEvent);
begin
  FOnIdle := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnIdle := NewValue;
end;


function TDesignApp.GetOnMessage: TMessageEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnMessage
  else
    Result := FOnMessage;
end;


procedure TDesignApp.SetOnMessage(NewValue: TMessageEvent);
begin
  FOnMessage := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnMessage := NewValue;
end;


function TDesignApp.GetOnMinimize: TNotifyEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnMinimize
  else
    Result := FOnMinimize;
end;


procedure TDesignApp.SetOnMinimize(NewValue: TNotifyEvent);
begin
  FOnMinimize := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnMinimize := NewValue;
end;


function TDesignApp.GetOnRestore: TNotifyEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnRestore
  else
    Result := FOnRestore;
end;


procedure TDesignApp.SetOnRestore(NewValue: TNotifyEvent);
begin
  FOnRestore := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnRestore := NewValue;
end;


function TDesignApp.GetOnShowHint: TShowHintEvent;
begin
  if not (csDesigning in ComponentState) then
    Result := Application.OnShowHint
  else
    Result := FOnShowHint;
end;


procedure TDesignApp.SetOnShowHint(NewValue: TShowHintEvent);
begin
  FOnShowHint := NewValue;
  if not (csDesigning in ComponentState) then
    Application.OnShowHint := NewValue;
end;








procedure Register;
begin
  RegisterComponents('NonVisual', [TDesignApp]);
end;



end.
